# Fshare command-line interface

fshare-cli - download files from fshare.vn by command-line

Compatible with Python >= 3.5

```
pip install fshare-cli
```

### Troubleshooting

You might need
```
sudo apt-get install libcurl4-openssl-dev libssl-dev -y
pip3 install --compile --install-option="--with-openssl" pycurl --force-reinstall
```
